from flask import Flask, jsonify, request
from flask_socketio import SocketIO, emit
import time

import config

app = Flask(__name__)
app.config['SECRET_KEY'] = config.SECRET_KEY
socketio = SocketIO(app, **config.SOCKET_IO_CONFIG)

@app.route("/send", methods=["POST"])
def send():
    """
    Bridges the message into the frontend

    JSON
    {
        event: Name of the event to emit
        data: data for the emission
    }
    """
    if not request.json:
        return jsonify({"success": False}), 400
    try:
        event = request.json["event"]
        data = request.json["data"]
    except KeyError:
        return jsonify({"success": False}), 400

    socketio.emit(event, data)
    return jsonify({"success": True})


if __name__ == '__main__':
    socketio.run(app, config.HOST, config.PORT)
